#
# spec file for package bat-extras
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define testsuite_version 6b97e0a531f77d2e1f10f48ebb68d4033d69e04d

Name:           bat-extras
Version:        2024.08.24
Release:        1.1
Summary:        Extra scripts for bat
License:        MIT
BuildArch:      noarch
Group:          Productivity/File utilities
URL:            https://github.com/eth-p/bat-extras
Source0:        https://github.com/eth-p/bat-extras/archive/v%{version}.tar.gz
Source1:        https://github.com/eth-p/best/archive/%{testsuite_version}.tar.gz
Requires:       bash
Requires:       bat
BuildRequires:  bat
BuildRequires:  ripgrep
BuildRequires:  shfmt
Recommends:     delta
Recommends:     entr
Recommends:     ripgrep

%description
Bash scripts that integrate bat with various command line tools.

%prep
%setup -q -a 1
rm -r '.test-framework'
mv best-%{testsuite_version}/ '.test-framework'

%build

%install
./build.sh --install --manuals --no-verify --minify=lib --prefix=%{buildroot}%{_prefix}
sed -i "s@/usr/bin/env bash@/bin/bash@" %{buildroot}%{_bindir}/*
install -Dm 0644 -t %{buildroot}%{_mandir}/man1 man/*

%check
./test.sh

%files
%defattr(-, root, root)
%license LICENSE.md
%{_mandir}/man1/*
%doc README.md
%{_bindir}/*

%changelog
* Sun Aug 25 2024 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 2024.08.24
  * prettybat: Use yq for YAML and JSON pretty formatting
  * batdiff: Support filenames with special characters
  * batman: Fix issues with trailing whitespace in MANPAGER
  * batman: Fix selecting manpages with aliases
  * batman: Allow --wrap to be passed to bat
* Tue Aug  6 2024 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 2024.07.10
  * batman: Provide way to use BATMAN as MANPAGER
  * prettybat: Add basic support for tsv files
  * prettybat: Don't add extra newlines to tsv for gnu
- Run tests in check stage
* Thu Feb 15 2024 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 2024.02.12
  * batman: Fix BAT_PAGER causing infinite recursion
  * batgrep: Add support for ripgrep-all
  * batman: Remove '-u' flag when calling sed
  * batman: Remove dependency on col program
  * Add Elixir mix format support
* Tue Sep 19 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 2023.09.19
  * batman: Split short options
  * batdiff: Show error when not in git repo
  * batdiff: Support filtering diffs by directory
  * batdiff: Check delta version for --hunk-style
  * batman: Document issues with non-default themes
  * batpipe: Add support for gzipped and bzipped tar files
  * batpipe: Extract batpipe_archive_header() helper function
  * all: Use eza instead of exa
* Sat Jun 17 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to release 2023-06-16
  * batdiff: Add '--staged' flag
  * batgrep: Add '--help'
  * batman: Use self as MANPAGER
  * prettybat: Fix short flags passed to bat
  * build: Add termux support
* Sat Mar 25 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to release 2023-03-21
  * batdiff: Update docs to add BATDIFF_USE_DELTA
  * batman: Allow spaces in manual sections
  * batman: Fix parsing manual pages in fzf preview
  * batman: Only parse first manpage when selected
  * batman: Fix bug where some man pages would fail to open
  * batpipe: Fix SELF variable being wrong when compressed
  * batpipe: Add BATPIPE_TERM_WIDTH
  * batpipe: Fix opened-in-less detection
  * batwatch docs: Fix link to entr project
  * docs: Update README about manual files
* Thu Jul 28 2022 Jan-Luca Kiok <me@jlk.one>
- Update to release 2022-07-27
  * batdiff: Fix use of deprecated --hunk-style
  * batman: Fix error when using fzf to pick manpages
  * batgrep: Pass -u flag to ripgrep
* Sun Apr 10 2022 Jan-Luca Kiok <me@jlk.one>
- Create man dir on install
* Sun Apr 10 2022 Jan-Luca Kiok <me@jlk.one>
- Use direct shell commands instead of indirect macros within the
  specfile
- Move man pages to their correct subdir
* Thu Apr  7 2022 Jan-Luca Kiok <me@jlk.one>
- Format spec file via osc service
* Sun Feb 27 2022 Jan-Luca Kiok <me@jlk.one>
- Change interpreter to bash instead of env
- Use macros instead of direct commands while installing
* Sun Feb 27 2022 Jan-Luca Kiok <me@jlk.one>
- Build and install manpages too
* Sun Feb 27 2022 Jan-Luca Kiok <me@jlk.one>
- Bump to 2021-08-21
  batgrep
  * Add support for '--' argument
  * Respect the BAT_STYLE environment variable
  * Add support for ripgrep 11
  batman
  * If fzf is installed, use batman to search through man pages
  * Only set grid style if BAT_STYLE is not defined
  batpipe
  * Fix colors not showing up inside less
  * Fix incorrect colors in usage instructions
  batwatch
  * Buffer --command mode to reduce flickering from redraw
  Docs
  * Fix manpage generation trimming spaces.
  * Fix manpage generation leaving <br/> tags inside man page.
* Sat Dec  5 2020 JL K <jlk@fsfe.org>
- Bump to 2020-10-05
* Sun Jul 12 2020 JL K <jlk@fsfe.org>
- Init package
